@@ -1,5 +1,8 @@
 #!/usr/bin/env python3
 
+from enum import Enum, auto
+from sys import stderr
+from textwrap import dedent
 from time import sleep
 from typing import Any, Mapping, NamedTuple, Optional, Text, Tuple, Union
 from pathlib import Path
@@ -53,7 +56,7 @@ def check_health():
 def check_login(username, password):
     print("\nChecking login details...")
 
-    url = api_route("check_login")
+    url = api_route(f"users/{username}/health")
     response = requests.get(url, auth=(str(username), str(password)))
 
     raise_on_error(response)
@@ -69,7 +72,7 @@ def check_credit(username, password):
     if isatty:
         print("\nChecking credit...")
 
-    url = api_route("check_credit")
+    url = api_route(f"users/{username}/credit")
     response = requests.get(url, auth=(str(username), str(password)))
 
     raise_on_error(response)
@@ -84,7 +87,7 @@ def check_credit(username, password):
 def change_password(username, old_password, new_password):
     print("\nChanging password...")
 
-    url = api_route("change_password")
+    url = api_route(f"users/{username}/change_password")
     headers = {"Content-Type": "application/json"}
     response = requests.patch(
         url,
@@ -158,7 +161,7 @@ def get_signed_url(
 ) -> Optional[SignedURL]:
     from sys import stderr
 
-    if Path(content_path).suffix not in {".jpg", ".jpeg", ".png", ".mp4"}:
+    if Path(content_path).suffix.lower() not in {".jpg", ".jpeg", ".png", ".mp4"}:
         print("Expected an image (.jpeg, .jpg, .png) or a video (.mp4).", file=stderr)
         return None
 
@@ -185,12 +188,13 @@ def upload_content(
 ):
     from sys import stderr
 
+    if fields is None:
+        fields = dict()
+
     filepath = Path(filepath)
     with filepath.open("rb") as fileobj:
         response = requests.post(
-            url,
-            data=dict(**fields),
-            files=dict(file=(str(filepath.relative_to(Path().absolute())), fileobj)),
+            url, data=dict(**fields), files=dict(file=(str(filepath), fileobj))
         )
 
     if not (200 <= response.status_code < 300):
@@ -204,26 +208,38 @@ def get_configuration(
     credentials: Tuple[Text, Text],
     content_handle: Text,
     config_filename: Union[Text, Path],
+    format: int = 1,
 ):
     total_waited = 0
     wait = 3
     print("Waiting for configuration", end="", flush=True)
-    while True:
-        if is_configuration_ready(content_handle, credentials):
+    status = config_status(content_handle, credentials)
+    for i in range(5):
+        if status != ConfigStatus.UNKNOWN:
             break
+        sleep(5)
+        status = config_status(content_handle, credentials)
+    else:
+        print(
+            "Having trouble starting the configuration process.",
+            file=stderr,
+            flush=True,
+        )
+        return
+    while status == ConfigStatus.RUNNING:
         sleep(wait)
+        status = config_status(content_handle, credentials)
         total_waited += wait
         print(".", end="", flush=True)
     print("")
+    if status != ConfigStatus.SUCCESS:
+        print("Creating configuration failed", file=stderr, flush=True)
+        return
     print("Retrieving configuration")
 
-    get_configuration_url = api_route("get_configuration")
+    get_configuration_url = api_route(f"contents/{content_handle}/format/{format}")
 
-    response = requests.get(
-        get_configuration_url,
-        params=dict(content_handle=content_handle),
-        auth=credentials,
-    )
+    response = requests.get(get_configuration_url, auth=credentials)
 
     raise_on_error(response)
 
@@ -242,11 +258,37 @@ def get_configuration(
     print("\nSuccessfully uploaded and configured content. \n")
 
 
-def is_configuration_ready(
-    content_handle: Text, credentials: Tuple[Text, Text]
-) -> bool:
-    url = api_route("is_configuration_ready")
-    response = requests.get(
-        url, params=dict(content_handle=content_handle), auth=credentials
-    )
-    return response.json().get("result", False)
+class ConfigStatus(Enum):
+    SUCCESS = auto()
+    FAILURE = auto()
+    RUNNING = auto()
+    UNKNOWN = auto()
+
+
+def config_status(content_handle: Text, credentials: Tuple[Text, Text]) -> ConfigStatus:
+    url = api_route(f"contents/{content_handle}/ready")
+
+    result = requests.get(url, auth=credentials)
+    if result.status_code != 200 or result.json() is None:
+        return ConfigStatus.UNKNOWN
+    if "error" in result.json():
+        return ConfigStatus.FAILURE
+    if result.json().get("status", "").lower() == "unknown":
+        return ConfigStatus.UNKNOWN
+    return ConfigStatus.SUCCESS if result.json()["result"] else ConfigStatus.RUNNING
+
+
+def get_contents(credentials: Tuple[Text, Text]):
+    route = api_route(f"users/{credentials[0]}/contents")
+    response = requests.get(route, auth=credentials)
+    raise_on_error(response)
+    for handle, data in response.json().items():
+        print(
+            dedent(
+                f"""
+            - handle: {handle}
+              creation: {data['creation']}
+              paid: {data['paid']}
+            """
+            ).strip(),
+        )
